@@ -127,14 +127,11 @@ describe 'mistral::api' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge!(OSDefaults.get_facts({
-          :concat_basedir => '/var/lib/puppet/concat',
-          :fqdn           => 'some.host.tld',
-        }))
+        facts.merge!(OSDefaults.get_facts())
       end
 
       let (:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :api_service_name => 'mistral-api' }
         when 'RedHat'
